
from pathlib import Path
from os import getenv

from dynaconf import Dynaconf

config_dir = Path(__file__).parent.resolve()

# Default fles.
settings_files = [
    config_dir / "restful_config.yaml",
    config_dir / "restful_config.secrets.yaml",
    Path("~/.config/pycalibration/cal_tools/restful_config.yaml").expanduser(),
]

if getenv('CAL_RESTFUL_TEST_CONFIG', None) == '1':
    settings_files.append(Path(
        "~/.config/pycalibration/cal_tools/restful_test_config.yaml").expanduser())


restful_config = Dynaconf(
    envvar_prefix="CAL_CAL_TOOLS",
    settings_files=settings_files,
    merge_enabled=True,
)


def calibration_client():
    """Obtain an initialized CalibrationClient object."""

    from calibration_client import CalibrationClient

    # Create client for CalCat.
    calcat_config = restful_config.get('calcat')
    return CalibrationClient(
        base_api_url=calcat_config['base-api-url'],
        use_oauth2=calcat_config['use-oauth2'],
        client_id=calcat_config['user-id'],
        client_secret=calcat_config['user-secret'],
        user_email=calcat_config['user-email'],
        token_url=calcat_config['token-url'],
        refresh_url=calcat_config['refresh-url'],
        auth_url=calcat_config['auth-url'],
        scope='')


def extra_calibration_client():
    """Obtain an initialized CalCatAPIClient object."""

    from cal_tools import calcat_interface2

    calcat_config = restful_config.get('calcat')
    user_id = user_secret = None
    if calcat_config['use-oauth2']:
        user_id, user_secret = calcat_config['user-id'], calcat_config['user-secret']

    base_api_url = calcat_config['base-api-url'].rstrip('/')
    assert base_api_url.endswith('/api')
    base_url = base_api_url[:-4]

    calcat_interface2.setup_client(
        base_url,
        client_id=user_id,
        client_secret=user_secret,
        user_email=calcat_config['user-email'],
    )
    if calcat_config['caldb-root']:
        calcat_interface2.set_default_caldb_root(Path(calcat_config['caldb-root']))
    return calcat_interface2.get_client()
