import sys
import unittest

import numpy as np
import xmlrunner
from correction_base import CorrectionTestBase, args, get_artefact_dir


class TestAGIPDCorrection(CorrectionTestBase, unittest.TestCase):
    detector = "AGIPD"
    task = "CORRECT"
    parms = {"in-folder": "/gpfs/exfel/exp/XMPL/201750/p700001/raw/AGIPD",
             "run": 412,
             "out-folder": "/gpfs/exfel/exp/XMPL/201750/p700001/scratch/AGIPD",
             "calfile": "/gpfs/exfel/exp/XMPL/201750/p700001/usr"
                        "/agipd_store.h5",
             "sequences": 0}
    hist_paths = {
        "INSTRUMENT/(.+)AGIPD(.+)/DET/[0-9]+CH0:xtdf/image/data":
            {
                "broad": {"bins": 10000, "range": (-1e4, 1e6)},
                "detail": {"bins": 10000, "range": (-100, 9900)}
            },
        "INSTRUMENT/(.+)AGIPD(.+)/DET/[0-9]+CH0:xtdf/image/mask":
            {
                "detail": {"bins": 32, "range": (0, 32),
                           "scl_fun": np.log2}
            },
        "INSTRUMENT/(.+)AGIPD(.+)/DET/[0-9]+CH0:xtdf/image/gain":
            {
                "detail": {"bins": 3, "range": (0, 3)}
            }
    }

    karabo_data_inspects = ['trailer.checksum', 'header.trainId',
                            'header.reserved',
                            'image.cellId', 'header.dataId', 'header.linkId',
                            'detector.data', 'metadata', 'image.length',
                            'header.magicNumberBegin',
                            'header.majorTrainFormatVersion',
                            'trailer.magicNumberEnd', 'image.status',
                            'image.trainId',
                            'image.pulseId', 'header.minorTrainFormatVersion',
                            'header.pulseCount', 'trailer.status',
                            'detector.trainId',
                            'trailer.trainId']

    expected_reports = ['AGIPDOfflineCorrection.pdf']

    def _output_to_path(self):
        opath = self.parms["out-folder"]
        run = int(self.parms["run"])
        return "{}/r{:04d}".format(opath, run)


if __name__ == '__main__':
    sys.argv[1:] = args.unittest_args

    loader = unittest.TestLoader()
    # make sure generators get run first
    ln = lambda f: "generate" not in f
    lncmp = lambda a, b: (ln(a) > ln(b)) - (ln(a) < ln(b))
    loader.sortTestMethodsUsing = lncmp
    output = get_artefact_dir(TestAGIPDCorrection)
    unittest.main(testLoader=loader,
                  testRunner=xmlrunner.XMLTestRunner(output=output),
                  verbosity=3, failfast=False, buffer=False, catchbreak=False)
